import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { SearchTeamOptions, SearchTeamResponse, GetRolesInfoOptions, GetRolesInfoResponse, UpdateTeamMemberAssignmentsOptions, UpdateTeamMemberAssignmentsResponse } from './index.typings.mjs';
export { AccountInfo, AccountInvite, AccountResourceContext, ApiCondition, ApiInviteAssignment, ApiPolicy, ApiResource, AreasFilter, AssignedPolicy, AssignedSubject, Assignment, AssignmentV3, ChangeRoleRequest, ChangeRoleResponse, ChangeRoleV2Options, ChangeRoleV2Request, ChangeRoleV2Response, CompanionResource, Condition, ConditionAttributeType, ConditionOperator, ConditionOperatorOperatorsOneOf, ConditionType, ConditionTypeOfOneOf, ConditionValue, ConditionValueValueOneOf, Conditions, Contributor, CreateCustomRoleRequest, CreateCustomRoleResponse, CustomRole, CustomRoleV2, DependOnOperator, Direction, EditorType, Effect, EnvironmentCondition, EnvironmentConditionConditionOneOf, EqualOperator, ExperimentCondition, ExperimentOperator, Facet, FacetType, FacetValue, FolderResource, FullNameResource, FullNameResourceResourceContextOneOf, GetPeopleRequest, GetPeopleResponse, GetPoliciesRequest, GetPoliciesResponse, GetRolesInfoRequest, GetRolesRequest, GetRolesResponse, GetRolesV2Request, GetRolesV2Response, GetScopesRequest, GetScopesResponse, GetSubjectsAssignmentsRequest, GetSubjectsAssignmentsResponse, GetTeamInvitesRequest, GetTeamInvitesResponse, GetTeamRequest, GetTeamResponse, GetTeamV2Response, GetUsersRequest, GetUsersResponse, Host, Invite, InviteAssignment, InviteAssignmentV3, InviteResourceAssignment, InviteStatus, InviteV3, JoinedCondition, JoinedConditionOperator, LikeOperator, LocationsRestriction, Name, OrderField, Ordering, OrganizationResourceContext, Paging, People, PeopleResource, PeopleResourceResourceTypeOneOf, PeopleType, PermissionScope, Person, PersonMetaData, PersonPersonOneOf, Policy, PolicyCondition, PolicyStatement, PolicyType, PredefinedRole, PredefinedRoleV2, PredefinedRoles, PredefinedRolesArea, PredefinedRolesAreaV2, RemoveMemberRequest, RemoveMemberResponse, Resource, ResourceType, Restriction, RestrictionRestrictionsOneOf, Role, RoleInfo, RoleInfoV2, RoleLevel, RoleLevelRestriction, RoleVisibility, RolesInfoFilter, ScopeArea, ScopeLevel, SearchTeamRequest, SimpleCondition, SimpleConditionOperator, SimpleConditionValue, SimpleConditionValueValueOneOf, SiteResourceContext, SiteRestriction, Subject, SubjectAssignments, SubjectContext, SubjectContextType, SubjectType, TeamMember, TeamMemberV3, TeamMemberV3MembersOneOf, UpdateTeamMemberAssignmentsRequest, User, UserV3, Visibility } from './index.typings.mjs';

declare function removeMember$1(httpClient: HttpClient): RemoveMemberSignature;
interface RemoveMemberSignature {
    /**
     * Removes a team member from the requesting account.
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - User ID of the team member to remove.
     */
    (userId: string): Promise<void>;
}
declare function searchTeam$1(httpClient: HttpClient): SearchTeamSignature;
interface SearchTeamSignature {
    /**
     * Retrieves all team members of the requesting account, based on the provided filters and free text queries.
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - Filter options.
     */
    (options?: SearchTeamOptions | undefined): Promise<SearchTeamResponse>;
}
declare function getRolesInfo$1(httpClient: HttpClient): GetRolesInfoSignature;
interface GetRolesInfoSignature {
    /**
     * Retrieves all available roles in the requesting account, including predefined and custom roles.
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - Filter options.
     */
    (options?: GetRolesInfoOptions | undefined): Promise<GetRolesInfoResponse>;
}
declare function updateTeamMemberAssignments$1(httpClient: HttpClient): UpdateTeamMemberAssignmentsSignature;
interface UpdateTeamMemberAssignmentsSignature {
    /**
     * Updates the assignments of roles and conditions for an existing team member.  Changing assignments changes the team member’s access to account assets.
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - ID of team member being affected.
     * @param - Filter options. The `assignmentIdsToRemove` and `newAssignments` fields **must** be passed.
     */
    (userId: string, options: UpdateTeamMemberAssignmentsOptions): Promise<UpdateTeamMemberAssignmentsResponse>;
}

declare const removeMember: MaybeContext<BuildRESTFunction<typeof removeMember$1> & typeof removeMember$1>;
declare const searchTeam: MaybeContext<BuildRESTFunction<typeof searchTeam$1> & typeof searchTeam$1>;
declare const getRolesInfo: MaybeContext<BuildRESTFunction<typeof getRolesInfo$1> & typeof getRolesInfo$1>;
declare const updateTeamMemberAssignments: MaybeContext<BuildRESTFunction<typeof updateTeamMemberAssignments$1> & typeof updateTeamMemberAssignments$1>;

export { GetRolesInfoOptions, GetRolesInfoResponse, SearchTeamOptions, SearchTeamResponse, UpdateTeamMemberAssignmentsOptions, UpdateTeamMemberAssignmentsResponse, getRolesInfo, removeMember, searchTeam, updateTeamMemberAssignments };
