import { NonNullablePaths } from '@wix/sdk-types';

interface User {
    /** User ID. */
    _id?: string;
    /**
     * Deprecated.
     * @deprecated
     */
    roles?: string[];
    /** User's email address. */
    email?: string;
    /** User's name. */
    name?: Name;
    /** URL to user's profile image, when provided. */
    profileImage?: string | null;
    /** Date the user joined the team. */
    joinedTeamAt?: Date | null;
    /**
     * Deprecated.
     * @deprecated
     */
    policyIds?: string[];
    /** Resources the user can access. */
    assignments?: Assignment[];
}
interface Name {
    /** User's first name. */
    firstName?: string;
    /** User's last name. */
    lastName?: string;
}
interface Assignment {
    /** Role assigned to the user. */
    policy?: AssignedPolicy;
    /** Unique ID for this specific assignment. */
    assignmentId?: string;
    /** Identity assigned to the asset in an assignment, referred to as subject. Supported subjects include user IDs, account IDs, and app IDs. */
    subject?: Subject;
}
interface AssignedPolicy {
    /** Role ID. */
    policyId?: string;
    /** Role title. */
    title?: string | null;
    /** Role description. */
    description?: string | null;
}
interface Restriction extends RestrictionRestrictionsOneOf {
    /**
     * Deprecated.
     * @deprecated
     */
    resource?: ApiResource;
    /** List of conditions restricting the user's access. Currently only folder conditions are supported. */
    conditions?: Conditions;
    /** Site where the assignment restrictions apply. */
    site?: SiteRestriction;
    /** Location where the assignment restrictions apply. */
    locations?: LocationsRestriction;
}
/** @oneof */
interface RestrictionRestrictionsOneOf {
    /**
     * Deprecated.
     * @deprecated
     */
    resource?: ApiResource;
    /** List of conditions restricting the user's access. Currently only folder conditions are supported. */
    conditions?: Conditions;
    /** Site where the assignment restrictions apply. */
    site?: SiteRestriction;
    /** Location where the assignment restrictions apply. */
    locations?: LocationsRestriction;
}
interface ApiResource {
    /** Resource type. */
    resourceType?: ResourceTypeWithLiterals;
    /** Resource ID. */
    _id?: string;
    value?: string | null;
}
declare enum ResourceType {
    UNKNOWN_RESOURCE_TYPE = "UNKNOWN_RESOURCE_TYPE",
    SITE = "SITE"
}
/** @enumType */
type ResourceTypeWithLiterals = ResourceType | 'UNKNOWN_RESOURCE_TYPE' | 'SITE';
interface Conditions {
    /** List of conditions. */
    conditions?: ApiCondition[];
}
interface ApiCondition {
    /** Condition type. */
    conditionType?: ConditionAttributeTypeWithLiterals;
    /** Condition ID. */
    _id?: string;
    /** Expected value of the condition. When `conditionType` = "FOLDER", this is the folder path. */
    value?: string | null;
}
declare enum ConditionAttributeType {
    UNKNOWN_CONDITION_TYPE = "UNKNOWN_CONDITION_TYPE",
    FOLDER = "FOLDER"
}
/** @enumType */
type ConditionAttributeTypeWithLiterals = ConditionAttributeType | 'UNKNOWN_CONDITION_TYPE' | 'FOLDER';
interface SiteRestriction {
    /** Site ID. */
    _id?: string;
    /** Site name. */
    value?: string | null;
}
interface CompanionResource {
    /** Asset ID (referred to here as resource ID). */
    _id?: string;
    /** Asset type (referred to here as resource type). as predefined in the authorization system */
    resourceType?: string;
}
interface LocationsRestriction {
    /**
     * Location IDs.
     * @format GUID
     * @maxSize 20
     */
    ids?: string[];
}
interface Subject {
    /** ID of identity assigned to the asset. */
    _id?: string;
    /** Type of identity assigned to the asset. Supported subject types include user IDs, account IDs, and app IDs. */
    subjectType?: SubjectTypeWithLiterals;
    /** Context of identity assigned to the asset. For example, a `subjectType` = `USER` will have `context` = `ACCOUNT`. */
    context?: SubjectContext;
}
declare enum SubjectType {
    UNKNOWN = "UNKNOWN",
    ACCOUNT = "ACCOUNT",
    USER = "USER",
    USER_GROUP = "USER_GROUP",
    MEMBER_GROUP = "MEMBER_GROUP",
    VISITOR_GROUP = "VISITOR_GROUP",
    EXTERNAL_APP = "EXTERNAL_APP",
    ACCOUNT_GROUP = "ACCOUNT_GROUP",
    WIX_APP = "WIX_APP"
}
/** @enumType */
type SubjectTypeWithLiterals = SubjectType | 'UNKNOWN' | 'ACCOUNT' | 'USER' | 'USER_GROUP' | 'MEMBER_GROUP' | 'VISITOR_GROUP' | 'EXTERNAL_APP' | 'ACCOUNT_GROUP' | 'WIX_APP';
interface SubjectContext {
    _id?: string;
    contextType?: SubjectContextTypeWithLiterals;
}
declare enum SubjectContextType {
    UNKNOWN_CTX = "UNKNOWN_CTX",
    ORG_CTX = "ORG_CTX",
    ACCOUNT_CTX = "ACCOUNT_CTX"
}
/** @enumType */
type SubjectContextTypeWithLiterals = SubjectContextType | 'UNKNOWN_CTX' | 'ORG_CTX' | 'ACCOUNT_CTX';
interface GetTeamRequest {
    /** @deprecated */
    usersLimit?: number | null;
    /** The locale of the request. Defaults to en */
    locale?: string | null;
    paging?: Paging;
}
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface GetTeamResponse {
    users?: User[];
    invites?: AccountInvite[];
    accountInfo?: AccountInfo;
    permissions?: string[];
    userId?: string;
    targetAccountId?: string;
    policies?: ApiPolicy[];
    totalUsersInAccount?: string;
    predefinedRoles?: PredefinedRoles;
}
interface AccountInvite {
    /**
     * Invite ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * Account ID.
     * @format GUID
     * @readonly
     */
    accountId?: string;
    /**
     * Email address where the invite was sent.
     * @format EMAIL
     */
    email?: string;
    /**
     * Deprecated. Use `policyIds`.
     * @deprecated
     */
    role?: string;
    /**
     * Deprecated. Use `inviterAccountId`.
     * @readonly
     * @deprecated
     */
    inviterId?: string;
    /**
     * Invite status.
     *
     * Supported values:
     * - **Pending:** The invite has been sent and is valid, waiting for the user's response.
     * - **Used:** The invite has been accepted.
     * - **Deleted:** The invite has been deleted or revoked.
     * - **Declined:** The user has declined the invite.
     * - **Expired:** The invite has expired without being accepted.
     */
    status?: InviteStatusWithLiterals;
    /** Link to accept the invite. */
    acceptLink?: string;
    /**
     * Inviting account ID.
     * @format GUID
     * @readonly
     */
    inviterAccountId?: string;
    /**
     * Account ID that accepted the invite. Populated only once the invite is accepted.
     * @format GUID
     * @readonly
     */
    acceptedByAccountId?: string | null;
    /** Date the invite was created. */
    dateCreated?: Date | null;
    /** Role IDs included in the invite. */
    policyIds?: string[];
    /** Date the invite was last updated. */
    dateUpdated?: Date | null;
    /** Assets the users are invited to join. */
    assignments?: InviteResourceAssignment[];
    /** Invite expiration date. */
    expirationDate?: Date | null;
}
/** Invite status stating whether the invite was accepted, waiting to be accepted, deleted etc.. */
declare enum InviteStatus {
    Pending = "Pending",
    Used = "Used",
    Deleted = "Deleted",
    Declined = "Declined",
    Expired = "Expired"
}
/** @enumType */
type InviteStatusWithLiterals = InviteStatus | 'Pending' | 'Used' | 'Deleted' | 'Declined' | 'Expired';
interface InviteResourceAssignment {
    /** Role ID. */
    policyId?: string;
    /** Resources the user will be able to access. */
    assignments?: InviteAssignment[];
}
interface InviteAssignment {
    /** Full name of resource to be assigned. */
    fullNameResource?: FullNameResource;
}
interface FullNameResource extends FullNameResourceResourceContextOneOf {
    /** Specific site details. */
    siteContext?: SiteResourceContext;
    /** Specific account details. */
    accountContext?: AccountResourceContext;
}
/** @oneof */
interface FullNameResourceResourceContextOneOf {
    /** Specific site details. */
    siteContext?: SiteResourceContext;
    /** Specific account details. */
    accountContext?: AccountResourceContext;
}
/** Site resource context. It indicates that the resource is under a site (can be the site itself or some asset of a site, like a blog post) */
interface SiteResourceContext {
    /** Site ID. */
    metasiteId?: string;
}
/** Account resource contexts. It indicates that the resource is under the account (can be the account itself or some asset of an account, like a logo or a domain) */
interface AccountResourceContext {
    /** Account ID. */
    accountId?: string;
}
interface OrganizationResourceContext {
}
/**
 * A custom resource. Is used to represent some asset that is not a direct resource context (site or account), but something custom.
 * For example: payment method, blog post, domain, logo.
 */
interface Resource {
    /** The resource id. */
    _id?: string | null;
    /** The resource type */
    type?: string | null;
}
interface PolicyCondition {
    /** The type of the condition */
    condition?: ConditionType;
}
interface ConditionType extends ConditionTypeOfOneOf {
    /** @deprecated */
    simpleCondition?: SimpleCondition;
    /** A logic combination between several conditions, with an operator between them */
    joinedConditions?: JoinedCondition;
    /** @deprecated */
    environmentCondition?: EnvironmentCondition;
    /** A single condition */
    condition?: Condition;
}
/** @oneof */
interface ConditionTypeOfOneOf {
    /** @deprecated */
    simpleCondition?: SimpleCondition;
    /** A logic combination between several conditions, with an operator between them */
    joinedConditions?: JoinedCondition;
    /** @deprecated */
    environmentCondition?: EnvironmentCondition;
    /** A single condition */
    condition?: Condition;
}
interface SimpleCondition {
    attrName?: string;
    value?: SimpleConditionValue;
    op?: SimpleConditionOperatorWithLiterals;
    conditionModelId?: string;
}
interface SimpleConditionValue extends SimpleConditionValueValueOneOf {
    attrName?: string;
    stringValue?: string;
    boolValue?: boolean;
}
/** @oneof */
interface SimpleConditionValueValueOneOf {
    attrName?: string;
    stringValue?: string;
    boolValue?: boolean;
}
declare enum SimpleConditionOperator {
    UNKNOWN_SIMPLE_OP = "UNKNOWN_SIMPLE_OP",
    EQUAL = "EQUAL"
}
/** @enumType */
type SimpleConditionOperatorWithLiterals = SimpleConditionOperator | 'UNKNOWN_SIMPLE_OP' | 'EQUAL';
interface JoinedCondition {
    /** The operator that should be used when evaluating the condition */
    op?: JoinedConditionOperatorWithLiterals;
    /** The conditions that should be evaluated, and then joined using the operator provided */
    conditions?: ConditionType[];
}
declare enum JoinedConditionOperator {
    UNKNOWN_JOIN_OP = "UNKNOWN_JOIN_OP",
    OR = "OR",
    AND = "AND"
}
/** @enumType */
type JoinedConditionOperatorWithLiterals = JoinedConditionOperator | 'UNKNOWN_JOIN_OP' | 'OR' | 'AND';
interface EnvironmentCondition extends EnvironmentConditionConditionOneOf {
    experimentCondition?: ExperimentCondition;
}
/** @oneof */
interface EnvironmentConditionConditionOneOf {
    experimentCondition?: ExperimentCondition;
}
interface ExperimentCondition {
    spec?: string;
    fallbackValue?: string;
    expectedValue?: string;
}
interface Condition {
    /** The unique identifier of the condition model. Indicates which actions the condition is working on */
    conditionModelId?: string;
    /** The operator that should be evaluated */
    operator?: ConditionOperator;
}
interface ConditionOperator extends ConditionOperatorOperatorsOneOf {
    /** Comparison of equality - will be evaluated to true if the given parties are equal */
    equals?: EqualOperator;
    /** Regex operator - will be evaluated to true if the given value matches the provided regex */
    like?: LikeOperator;
    /** Petri experiment - will be evaluated using petri. */
    experiment?: ExperimentOperator;
    /** Operator that indicates a dependency on another subject being allowed to perform something. */
    dependOn?: DependOnOperator;
}
/** @oneof */
interface ConditionOperatorOperatorsOneOf {
    /** Comparison of equality - will be evaluated to true if the given parties are equal */
    equals?: EqualOperator;
    /** Regex operator - will be evaluated to true if the given value matches the provided regex */
    like?: LikeOperator;
    /** Petri experiment - will be evaluated using petri. */
    experiment?: ExperimentOperator;
    /** Operator that indicates a dependency on another subject being allowed to perform something. */
    dependOn?: DependOnOperator;
}
interface EqualOperator {
    /** The attribute which should be compared. The attribute will be first evaluated to a value, and then compared the other side (attribute/value) */
    attrName?: string;
    /** The value to compare to. If the two parties are equal - we will return true. */
    value?: ConditionValue;
}
interface ConditionValue extends ConditionValueValueOneOf {
    /** an attribute. We'll first retrieve the value of the attribute (from the request or from pre-indexed values), and then compare to what it needs to be compared with. */
    attrName?: string;
    /** a value with a string type. Will be compared to the attribute provided, and be true only if they match the operator. */
    stringValue?: string;
    /** a value with a boolean type. Will be compared to the attribute provided, and be true only if they match the operator. */
    boolValue?: boolean;
}
/** @oneof */
interface ConditionValueValueOneOf {
    /** an attribute. We'll first retrieve the value of the attribute (from the request or from pre-indexed values), and then compare to what it needs to be compared with. */
    attrName?: string;
    /** a value with a string type. Will be compared to the attribute provided, and be true only if they match the operator. */
    stringValue?: string;
    /** a value with a boolean type. Will be compared to the attribute provided, and be true only if they match the operator. */
    boolValue?: boolean;
}
interface LikeOperator {
    /** The attribute which should be compared. The attribute will be first evaluated to a value, and then compared the regex values provided. */
    attrName?: string;
    /** The regex values which the attribute value should be evaluated on. If the attribute value matches at least one of the regular expressions provided - we will return true */
    values?: string[];
}
interface ExperimentOperator {
    /** The spec to conduct the experiment on. */
    spec?: string;
    /** The value to use if the experiment could not be conducted */
    fallbackValue?: string;
    /** The expected value of the experiment conduction. If it matches the actual value - true will be returned. Otherwise - false. */
    expectedValue?: string;
}
/** Implies that the policy takes affect only if the depend on subject is permitted as well. */
interface DependOnOperator {
    /** The subject on which the current entry depends on. If the subject is allowed to perform what the query was about - the condition will be evaluated to true. Otherwise - false */
    dependOnSubject?: Subject;
}
interface AccountInfo {
    accountName?: string;
    accountImage?: string;
    isTeam?: boolean;
}
interface ApiPolicy {
    _id?: string;
    description?: string | null;
    name?: string | null;
    isCustom?: boolean;
    scopes?: string[];
}
interface PredefinedRoles {
    roles?: PredefinedRole[];
}
interface PredefinedRole {
    titleKey?: string;
    roles?: Role[];
    title?: string | null;
    areaId?: string;
}
interface Role {
    _id?: string;
    deprecatedKey?: string;
    /** @deprecated */
    titleKey?: string;
    /** @deprecated */
    descriptionKey?: string;
    deprecated?: boolean;
    restrictFromLevel?: string;
    experiments?: string[];
    appDefIds?: string[];
    title?: string | null;
    description?: string | null;
    isCustom?: boolean;
    scopes?: string[];
    availableResourceTypes?: ResourceTypeWithLiterals[];
    availableConditions?: ConditionAttributeTypeWithLiterals[];
    limitToEditorTypes?: string[];
}
interface ChangeRoleRequest {
    /** User ID. */
    _id?: string;
    /**
     * Deprecated. Use `policyIds`.
     * @deprecated
     */
    role?: string;
    /** Role IDs to be assigned. */
    policyIds?: string[];
}
interface ChangeRoleResponse {
}
interface RemoveMemberRequest {
    /** User ID of the team member to remove. */
    userId: string;
}
interface RemoveMemberResponse {
}
interface GetUsersRequest {
    /** The number of items to load */
    limit?: number | null;
    /** number of items to skip in the current sort order */
    offset?: number | null;
}
interface GetUsersResponse {
    users?: User[];
}
interface GetScopesRequest {
    /** The locale of the request. Defaults to en */
    locale?: string | null;
}
interface GetScopesResponse {
    scopeAreas?: ScopeArea[];
}
interface ScopeArea {
    title?: string;
    appDefIds?: string[];
    scopes?: PermissionScope[];
    restrictFromLevel?: ScopeLevelWithLiterals;
}
interface PermissionScope {
    _id?: string;
    title?: string;
    description?: string;
    level?: ScopeLevelWithLiterals;
    experiments?: string[];
    dependantScopes?: string[];
    restrictFromLevel?: ScopeLevelWithLiterals;
    deprecated?: boolean | null;
    /** The visibility of the scope for the caller */
    visibility?: VisibilityWithLiterals;
    /**
     * @maxSize 20
     * @format GUID
     */
    appDefIds?: string[];
}
declare enum ScopeLevel {
    None = "None",
    SITE = "SITE",
    ACCOUNT = "ACCOUNT"
}
/** @enumType */
type ScopeLevelWithLiterals = ScopeLevel | 'None' | 'SITE' | 'ACCOUNT';
declare enum Visibility {
    /** The scope should be visible to the caller */
    VISIBLE = "VISIBLE",
    /** The scope shouldn't be visible for the caller, because the capability that blocks it is turned on for the caller */
    BLOCKED_BY_CAPABILITY = "BLOCKED_BY_CAPABILITY"
}
/** @enumType */
type VisibilityWithLiterals = Visibility | 'VISIBLE' | 'BLOCKED_BY_CAPABILITY';
interface GetPeopleRequest {
    resource?: PeopleResource;
    peopleType?: PeopleTypeWithLiterals;
    paging?: Paging;
    /** The locale of the request. Defaults to en */
    locale?: string | null;
}
interface PeopleResource extends PeopleResourceResourceTypeOneOf {
    site?: string;
    folder?: FolderResource;
}
/** @oneof */
interface PeopleResourceResourceTypeOneOf {
    site?: string;
    folder?: FolderResource;
}
interface FolderResource {
    folderId?: string;
    folderFullPath?: string;
}
declare enum PeopleType {
    UNDEF_PEOPLE_TYPE = "UNDEF_PEOPLE_TYPE",
    CONTRIBUTOR = "CONTRIBUTOR",
    TEAM_MEMBER = "TEAM_MEMBER"
}
/** @enumType */
type PeopleTypeWithLiterals = PeopleType | 'UNDEF_PEOPLE_TYPE' | 'CONTRIBUTOR' | 'TEAM_MEMBER';
interface GetPeopleResponse {
    people?: People;
}
interface People {
    people?: Person[];
    totalPeople?: number;
}
interface Person extends PersonPersonOneOf {
    contributor?: Contributor;
    teamMember?: TeamMember;
}
/** @oneof */
interface PersonPersonOneOf {
    contributor?: Contributor;
    teamMember?: TeamMember;
}
interface Contributor {
    /** Contributor's metadata. */
    metaData?: PersonMetaData;
    /** Whether the contributor account is a team account. */
    isTeam?: boolean | null;
    /** Date that the contributor joined the site. */
    joinedAt?: Date | null;
    /** Email address that received the invite. */
    invitedEmail?: string | null;
    /** Whether the contributor account is a client account. */
    isClient?: boolean | null;
    /**
     * Contributor's user ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
}
interface PersonMetaData {
    /** Contributor's account ID. */
    _id?: string;
    /** Contributor's full name. */
    fullName?: string | null;
    /** URL for contributor's profile image. */
    imageUrl?: string | null;
    /** Contributor's email address. */
    email?: string | null;
    /** Contributor's access to assets and their assigned role (`policy`) for that asset. */
    assignments?: Assignment[];
}
interface TeamMember {
    metaData?: PersonMetaData;
}
interface GetTeamV2Response {
    users?: User[];
    totalUsersInAccount?: string;
}
interface GetTeamInvitesRequest {
    /** The locale of the request. Defaults to en */
    locale?: string | null;
}
interface GetTeamInvitesResponse {
    invites?: Invite[];
}
interface Invite {
    /**
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * @format GUID
     * @readonly
     */
    accountId?: string;
    email?: string;
    status?: InviteStatusWithLiterals;
    acceptLink?: string;
    dateCreated?: Date | null;
    dateUpdated?: Date | null;
    assignments?: ApiInviteAssignment[];
    /** Invite expiration date */
    expirationDate?: Date | null;
}
interface ApiInviteAssignment {
    policy?: AssignedPolicy;
    restrictions?: Restriction;
}
interface GetPoliciesRequest {
    /** The locale of the request. Defaults to en */
    locale?: string | null;
    /** Areas filter to include only roles from areas that pass this filter. When not provided, roles from all areas will be returned */
    areasFilter?: AreasFilter;
    /** Role level filter to include only roles that are not restricted from the requested resource level (site/account). When set to ALL, all levels are returned */
    roleLevel?: RoleLevelWithLiterals;
}
interface AreasFilter {
    /** A list of role area ids, to filter only roles belonging to these areas */
    areaIds?: string[];
}
declare enum RoleLevel {
    ALL = "ALL",
    SITE_LEVEL = "SITE_LEVEL",
    ACCOUNT_LEVEL = "ACCOUNT_LEVEL"
}
/** @enumType */
type RoleLevelWithLiterals = RoleLevel | 'ALL' | 'SITE_LEVEL' | 'ACCOUNT_LEVEL';
interface GetPoliciesResponse {
    policies?: PredefinedRoles;
}
interface SearchTeamRequest {
    /** Free text to search for within team member name and email address fields. */
    query?: string | null;
    /** Sort data. */
    orderBy?: Ordering[];
    /**
     * Filter object. Supported values: `inviteType` and `roleId`. For example, `{'inviteType': {'$eq': 'Expired'}}`.
     * See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language) for more information.
     */
    filter?: Record<string, any> | null;
    /**
     * A list of facets to return in the response. Facets count the items within logical groupings.
     * See [Filters and Facets: An Explainer](https://medium.com/@westontt/filters-and-facets-an-explainer-3b73a9538eca) for more information.
     */
    facets?: FacetTypeWithLiterals[];
    /** Pagination. */
    paging?: Paging;
}
interface Ordering {
    /** Field to sort by. */
    fieldName?: OrderFieldWithLiterals;
    /** Sort order. */
    direction?: DirectionWithLiterals;
}
declare enum OrderField {
    /** For internal use. */
    Undefined = "Undefined",
    /** Team member name. */
    Name = "Name",
    /** Date team member joined the account. */
    JoinedAt = "JoinedAt"
}
/** @enumType */
type OrderFieldWithLiterals = OrderField | 'Undefined' | 'Name' | 'JoinedAt';
declare enum Direction {
    /** For internal use. */
    UninitializedDirection = "UninitializedDirection",
    /** Ascending. */
    ASC = "ASC",
    /** Descending. */
    DESC = "DESC"
}
/** @enumType */
type DirectionWithLiterals = Direction | 'UninitializedDirection' | 'ASC' | 'DESC';
declare enum FacetType {
    Undefined = "Undefined",
    /** How many team members with each role */
    Roles = "Roles",
    /** How many team members by invite status */
    InviteStatus = "InviteStatus",
    /** How many team members in total in the account */
    Users = "Users"
}
/** @enumType */
type FacetTypeWithLiterals = FacetType | 'Undefined' | 'Roles' | 'InviteStatus' | 'Users';
interface SearchTeamResponse {
    /** List of facets, as requested. */
    facets?: Facet[];
    /** Existing team members and invites sent to join the account. */
    teamMembers?: TeamMemberV3[];
}
interface Facet {
    /** Facet type. */
    facetType?: FacetTypeWithLiterals;
    /** Values and their counters. Values with count = 0 are not returned. */
    values?: FacetValue[];
}
interface FacetValue {
    /** Supported values: `Roles`, `InviteStatus`, `Users`. */
    value?: string;
    /** Number of existing items for the value. */
    count?: number;
}
interface TeamMemberV3 extends TeamMemberV3MembersOneOf {
    /** Existing team member data. */
    user?: UserV3;
    /** Invited team member data. */
    invite?: InviteV3;
}
/** @oneof */
interface TeamMemberV3MembersOneOf {
    /** Existing team member data. */
    user?: UserV3;
    /** Invited team member data. */
    invite?: InviteV3;
}
interface UserV3 {
    /** User ID. */
    _id?: string;
    /**
     * User's email address.
     * @format EMAIL
     */
    email?: string | null;
    /** User's name, when provided. */
    name?: Name;
    /** URL to user's profile image, when provided. */
    profileImage?: string | null;
    /** Date the user joined the team. */
    joinedTeamAt?: Date | null;
    /** Mapping of the user's access to an asset and their assigned role. */
    assignments?: AssignmentV3[];
}
interface AssignmentV3 {
    /** Role assigned to the user. To retrieve all available roles, call Get Roles Info. */
    policyId?: string | null;
    /**
     * Unique ID for this specific assignment.
     * @readonly
     */
    assignmentId?: string | null;
    /** The asset where a user is assigned access in an assignment. When empty, the role covers all assets, with no restrictions to specific sites or folders. */
    restrictions?: Restriction;
    /** Identity assigned to the asset in an assignment, referred to as subject. Supported subjects include user IDs, account IDs, and app IDs. */
    subject?: AssignedSubject;
}
interface AssignedSubject {
    /**
     * Identity ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /** Identity type. */
    subjectType?: SubjectTypeWithLiterals;
}
interface InviteV3 {
    /**
     * Invite ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /**
     * Invitee's email address.
     * @format EMAIL
     */
    email?: string | null;
    /** Invite status. */
    status?: InviteStatusWithLiterals;
    /** URL of direct link to accept the invite. */
    acceptLink?: string | null;
    /** Date the invite was created. */
    dateCreated?: Date | null;
    /** Date the invite was last updated. */
    dateUpdated?: Date | null;
    /** A list of assignments that will be applied to the invitees when they accept the invite. */
    assignments?: InviteAssignmentV3[];
    /** Invite expiration date. */
    expirationDate?: Date | null;
}
interface InviteAssignmentV3 {
    /** Role ID that will be assigned once the invite is accepted. */
    policyId?: string | null;
    /** Assets where the user will be assigned access. When empty, the role covers all assets, with no restrictions to specific sites or folders. */
    restrictions?: Restriction;
}
interface GetRolesRequest {
    /** The locale of the predefined roles names and descriptions. Defaults to English */
    locale?: string | null;
}
interface GetRolesResponse {
    /** The predefined roles (by areas) */
    predefinedRolesAreas?: PredefinedRolesArea[];
    /** The custom roles */
    customRoles?: CustomRole[];
}
interface PredefinedRolesArea {
    /** The id of the area (e.g "Blog") */
    areaId?: string;
    /** The translated area title, according to the request locale, or the original title if translation failed */
    title?: string;
    /** The predefined roles belonging to this area */
    roles?: PredefinedRoleV2[];
}
interface PredefinedRoleV2 {
    /** The policy id of this role */
    _id?: string;
    /** The title of this role, translated according to the request locale, or the original title if translation failed */
    title?: string;
    /** The description of this role, translated according to the request locale, or the original description if translation failed */
    description?: string;
    /** The permission-scopes this role's policy contains */
    scopes?: string[];
    /** Indicates if the role is deprecated (shouldn't be granted, and only exists for backward compatability) */
    deprecated?: boolean;
    /** Indicates if this role should be restricted from assignments of a specific resource type (if RoleLevelRestriction = None, there is no restriction) */
    restrictFromLevel?: RoleLevelRestrictionWithLiterals;
    /** Experiments that should be open for this role to be visible */
    experiments?: string[];
    /** Applications that should be installed for this role to be visible */
    appDefIds?: string[];
    /** Editor types this role should be limited to (if empty, available in all editors) */
    limitToEditorTypes?: EditorTypeWithLiterals[];
    /** The visibility of the role */
    visibility?: RoleVisibilityWithLiterals;
}
declare enum RoleLevelRestriction {
    NoRestriction = "NoRestriction",
    Site = "Site",
    Account = "Account"
}
/** @enumType */
type RoleLevelRestrictionWithLiterals = RoleLevelRestriction | 'NoRestriction' | 'Site' | 'Account';
declare enum EditorType {
    UNINITIALIZED = "UNINITIALIZED",
    EDITORX = "EDITORX",
    BLOCKS = "BLOCKS",
    STUDIO = "STUDIO"
}
/** @enumType */
type EditorTypeWithLiterals = EditorType | 'UNINITIALIZED' | 'EDITORX' | 'BLOCKS' | 'STUDIO';
declare enum RoleVisibility {
    /** the role should be visible to the caller */
    Visible = "Visible",
    /** the role should be disabled for the caller, because it contains permissions the caller wasn't granted on the call context (site/account) */
    Disabled_Dependency = "Disabled_Dependency",
    /** the role should be disabled for the caller, because the role's capability is disabled for the caller */
    Disabled_Capability = "Disabled_Capability"
}
/** @enumType */
type RoleVisibilityWithLiterals = RoleVisibility | 'Visible' | 'Disabled_Dependency' | 'Disabled_Capability';
interface CustomRole {
    /** The policy this role grants */
    policy?: ApiPolicy;
    /** The visibility of the role */
    visibility?: RoleVisibilityWithLiterals;
    /** Whether this role is assigned to a subject */
    assigned?: boolean | null;
}
interface GetRolesInfoRequest {
    /** Language of predefined roles names and descriptions to return, in ISO 639 format. Default: `en`. */
    locale?: string | null;
    /** Roles to return. */
    filter?: RolesInfoFilter;
}
interface RolesInfoFilter {
    /** Role level to return. Default: ALL. */
    roleLevel?: RoleLevelWithLiterals;
    /** Filter for editor-specific roles. Default: ALL. */
    editorTypes?: EditorTypeWithLiterals[];
}
interface GetRolesInfoResponse {
    /** Predefined roles. */
    predefinedRoles?: RoleInfo[];
    /** Custom roles. */
    customRoles?: RoleInfo[];
}
interface RoleInfo {
    /** Role ID. */
    _id?: string;
    /** Role title, translated according to the request locale. If translation fails, the original title is returned. */
    title?: string;
    /** Role description, translated according to the request locale. If translation fails, the original description is returned. */
    description?: string;
    /** Whether this role is restricted from accessing a specific resource type. Default: `NoRestriction`. */
    restrictFromLevel?: RoleLevelRestrictionWithLiterals;
}
interface CreateCustomRoleRequest {
    /** The custom role to create */
    role?: Policy;
}
interface Policy {
    /** @readonly */
    _id?: string | null;
    /** @maxLength 50 */
    name?: string | null;
    /** @maxLength 500 */
    description?: string | null;
    /** @readonly */
    status?: string;
    policyType?: PolicyTypeWithLiterals;
    statements?: PolicyStatement[];
}
declare enum PolicyType {
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    PREDEFINED = "PREDEFINED",
    CUSTOM = "CUSTOM",
    INLINE_CUSTOM = "INLINE_CUSTOM"
}
/** @enumType */
type PolicyTypeWithLiterals = PolicyType | 'UNKNOWN_STATUS' | 'PREDEFINED' | 'CUSTOM' | 'INLINE_CUSTOM';
interface PolicyStatement {
    /** @readonly */
    _id?: string | null;
    permissions?: string[];
    scopes?: string[];
    effect?: EffectWithLiterals;
    condition?: PolicyCondition;
}
declare enum Effect {
    UNKNOWN_EFFECT = "UNKNOWN_EFFECT",
    ALLOW = "ALLOW",
    DENY = "DENY"
}
/** @enumType */
type EffectWithLiterals = Effect | 'UNKNOWN_EFFECT' | 'ALLOW' | 'DENY';
interface CreateCustomRoleResponse {
    /** The newly created custom role */
    roleCreated?: Policy;
}
interface ChangeRoleV2Request {
    /**
     * ID of team member being affected.
     * @format GUID
     */
    userId: string;
    /** New assignments, including roles, to apply to the team member in this account. To retrieve all available roles, call Get Roles Info. */
    roles: AssignmentV3[];
    /** Existing assignment IDs to remove. To retrieve all existing assignment IDs for a team member, call Search Team. */
    assignmentIdsToReplace: string[];
}
interface ChangeRoleV2Response {
    /** New roles assigned to the given team member. */
    roles?: AssignmentV3[];
}
interface UpdateTeamMemberAssignmentsRequest {
    /**
     * ID of team member being affected.
     * @format GUID
     */
    userId: string;
    /**
     * New assignments to apply to the team member in this account.
     * @maxSize 50
     */
    newAssignments: AssignmentV3[];
    /**
     * Existing assignment IDs to remove. To retrieve all existing assignment IDs for a team member, call Search Team.
     * @format GUID
     * @maxSize 50
     */
    assignmentIdsToRemove: string[];
}
interface UpdateTeamMemberAssignmentsResponse {
    /** The new assignments, assigned to the given team member. */
    assignments?: AssignmentV3[];
}
interface GetSubjectsAssignmentsRequest {
    /** The locale of the request. Defaults to en */
    locale?: string | null;
    /** list of subjects */
    subjects?: Subject[];
}
interface GetSubjectsAssignmentsResponse {
    /** list of subjects with assignments */
    subjectsAssignments?: SubjectAssignments[];
}
interface SubjectAssignments {
    subject?: Subject;
    assignments?: Assignment[];
}
interface GetRolesV2Request {
    /**
     * The locale of the predefined roles names and descriptions. Defaults to English
     * @format LANGUAGE
     */
    locale?: string | null;
    /** The host platform to filter roles for */
    host?: HostWithLiterals;
}
/** Host represents the different platforms where roles can be applied. */
declare enum Host {
    /** Unspecified host. */
    INVALID_HOST = "INVALID_HOST",
    /** Business Manager platform. */
    BUSINESS_MANAGER = "BUSINESS_MANAGER",
    /** Channels platform. */
    CHANNELS = "CHANNELS",
    /** Enterprise platform. */
    ENTERPRISE = "ENTERPRISE",
    /** Studio platform. */
    STUDIO_HOST = "STUDIO_HOST",
    /** Dev Center platform. */
    DEV_CENTER = "DEV_CENTER"
}
/** @enumType */
type HostWithLiterals = Host | 'INVALID_HOST' | 'BUSINESS_MANAGER' | 'CHANNELS' | 'ENTERPRISE' | 'STUDIO_HOST' | 'DEV_CENTER';
interface GetRolesV2Response {
    /** The predefined roles (by areas) with simplified structure */
    predefinedRolesAreas?: PredefinedRolesAreaV2[];
    /** The custom roles with simplified structure */
    customRoles?: CustomRoleV2[];
}
interface PredefinedRolesAreaV2 {
    /**
     * Area ID
     * @maxLength 50
     */
    areaId?: string;
    /**
     * Area title
     * @maxLength 50
     */
    title?: string;
    /**
     * Roles in this area
     * @maxSize 100
     */
    roles?: RoleInfoV2[];
    /**
     * Host platforms this area applies to
     * @maxSize 10
     * @maxLength 50
     */
    hosts?: string[];
}
interface RoleInfoV2 {
    /**
     * Role ID
     * @maxLength 50
     */
    _id?: string;
    /**
     * Role title
     * @maxLength 500
     */
    title?: string;
    /**
     * Role description
     * @maxLength 1000
     */
    description?: string;
    /**
     * List of dependent role IDs
     * @maxSize 50
     * @maxLength 50
     */
    dependentRoles?: string[];
}
interface CustomRoleV2 {
    /**
     * Role ID
     * @maxLength 50
     */
    _id?: string;
    /**
     * Role title
     * @maxLength 500
     */
    title?: string;
    /**
     * Role description
     * @maxLength 1000
     */
    description?: string;
    /**
     * List of permission scopes
     * @maxSize 100
     * @maxLength 100
     */
    scopes?: string[];
    /** Whether this role is assigned to the current user */
    assigned?: boolean;
}
/**
 * Removes a team member from the requesting account.
 * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
 * @param userId - User ID of the team member to remove.
 * @public
 * @requiredField userId
 * @permissionId team.delete-member
 * @fqn com.wixpress.roles.management.api.RolesManagementService.RemoveMember
 */
declare function removeMember(userId: string): Promise<void>;
/**
 * Retrieves all team members of the requesting account, based on the provided filters and free text queries.
 * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
 * @public
 * @param options - Filter options.
 * @fqn com.wixpress.roles.management.api.RolesManagementService.SearchTeam
 */
declare function searchTeam(options?: SearchTeamOptions): Promise<NonNullablePaths<SearchTeamResponse, `facets` | `facets.${number}.facetType` | `teamMembers` | `teamMembers.${number}.user._id` | `teamMembers.${number}.user.name.firstName` | `teamMembers.${number}.user.name.lastName` | `teamMembers.${number}.invite._id` | `teamMembers.${number}.invite.status`>>;
interface SearchTeamOptions {
    /** Free text to search for within team member name and email address fields. */
    query?: string | null;
    /** Sort data. */
    orderBy?: Ordering[];
    /**
     * Filter object. Supported values: `inviteType` and `roleId`. For example, `{'inviteType': {'$eq': 'Expired'}}`.
     * See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language) for more information.
     */
    filter?: Record<string, any> | null;
    /**
     * A list of facets to return in the response. Facets count the items within logical groupings.
     * See [Filters and Facets: An Explainer](https://medium.com/@westontt/filters-and-facets-an-explainer-3b73a9538eca) for more information.
     */
    facets?: FacetTypeWithLiterals[];
    /** Pagination. */
    paging?: Paging;
}
/**
 * Retrieves all available roles in the requesting account, including predefined and custom roles.
 * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
 * @public
 * @param options - Filter options.
 * @permissionId ACCOUNT_ROLES.GET_ROLES
 * @fqn com.wixpress.roles.management.api.RolesManagementService.GetRolesInfo
 */
declare function getRolesInfo(options?: GetRolesInfoOptions): Promise<NonNullablePaths<GetRolesInfoResponse, `predefinedRoles` | `predefinedRoles.${number}._id` | `predefinedRoles.${number}.title` | `predefinedRoles.${number}.description` | `predefinedRoles.${number}.restrictFromLevel` | `customRoles` | `customRoles.${number}._id` | `customRoles.${number}.title` | `customRoles.${number}.description` | `customRoles.${number}.restrictFromLevel`>>;
interface GetRolesInfoOptions {
    /** Language of predefined roles names and descriptions to return, in ISO 639 format. Default: `en`. */
    locale?: string | null;
    /** Roles to return. */
    filter?: RolesInfoFilter;
}
interface ChangeRoleV2Options {
    /** New assignments, including roles, to apply to the team member in this account. To retrieve all available roles, call Get Roles Info. */
    roles: AssignmentV3[];
    /** Existing assignment IDs to remove. To retrieve all existing assignment IDs for a team member, call Search Team. */
    assignmentIdsToReplace: string[];
}
/**
 * Updates the assignments of roles and conditions for an existing team member.  Changing assignments changes the team member’s access to account assets.
 * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
 * @param userId - ID of team member being affected.
 * @public
 * @requiredField options
 * @requiredField options.assignmentIdsToRemove
 * @requiredField options.newAssignments
 * @requiredField userId
 * @param options - Filter options. The `assignmentIdsToRemove` and `newAssignments` fields **must** be passed.
 * @permissionId team.manage-team-member-roles
 * @fqn com.wixpress.roles.management.api.RolesManagementService.UpdateTeamMemberAssignments
 */
declare function updateTeamMemberAssignments(userId: string, options: NonNullablePaths<UpdateTeamMemberAssignmentsOptions, `assignmentIdsToRemove` | `newAssignments`>): Promise<NonNullablePaths<UpdateTeamMemberAssignmentsResponse, `assignments` | `assignments.${number}.restrictions.resource.resourceType` | `assignments.${number}.restrictions.resource._id` | `assignments.${number}.restrictions.site._id` | `assignments.${number}.subject._id` | `assignments.${number}.subject.subjectType`>>;
interface UpdateTeamMemberAssignmentsOptions {
    /**
     * New assignments to apply to the team member in this account.
     * @maxSize 50
     */
    newAssignments: AssignmentV3[];
    /**
     * Existing assignment IDs to remove. To retrieve all existing assignment IDs for a team member, call Search Team.
     * @format GUID
     * @maxSize 50
     */
    assignmentIdsToRemove: string[];
}

export { type AccountInfo, type AccountInvite, type AccountResourceContext, type ApiCondition, type ApiInviteAssignment, type ApiPolicy, type ApiResource, type AreasFilter, type AssignedPolicy, type AssignedSubject, type Assignment, type AssignmentV3, type ChangeRoleRequest, type ChangeRoleResponse, type ChangeRoleV2Options, type ChangeRoleV2Request, type ChangeRoleV2Response, type CompanionResource, type Condition, ConditionAttributeType, type ConditionAttributeTypeWithLiterals, type ConditionOperator, type ConditionOperatorOperatorsOneOf, type ConditionType, type ConditionTypeOfOneOf, type ConditionValue, type ConditionValueValueOneOf, type Conditions, type Contributor, type CreateCustomRoleRequest, type CreateCustomRoleResponse, type CustomRole, type CustomRoleV2, type DependOnOperator, Direction, type DirectionWithLiterals, EditorType, type EditorTypeWithLiterals, Effect, type EffectWithLiterals, type EnvironmentCondition, type EnvironmentConditionConditionOneOf, type EqualOperator, type ExperimentCondition, type ExperimentOperator, type Facet, FacetType, type FacetTypeWithLiterals, type FacetValue, type FolderResource, type FullNameResource, type FullNameResourceResourceContextOneOf, type GetPeopleRequest, type GetPeopleResponse, type GetPoliciesRequest, type GetPoliciesResponse, type GetRolesInfoOptions, type GetRolesInfoRequest, type GetRolesInfoResponse, type GetRolesRequest, type GetRolesResponse, type GetRolesV2Request, type GetRolesV2Response, type GetScopesRequest, type GetScopesResponse, type GetSubjectsAssignmentsRequest, type GetSubjectsAssignmentsResponse, type GetTeamInvitesRequest, type GetTeamInvitesResponse, type GetTeamRequest, type GetTeamResponse, type GetTeamV2Response, type GetUsersRequest, type GetUsersResponse, Host, type HostWithLiterals, type Invite, type InviteAssignment, type InviteAssignmentV3, type InviteResourceAssignment, InviteStatus, type InviteStatusWithLiterals, type InviteV3, type JoinedCondition, JoinedConditionOperator, type JoinedConditionOperatorWithLiterals, type LikeOperator, type LocationsRestriction, type Name, OrderField, type OrderFieldWithLiterals, type Ordering, type OrganizationResourceContext, type Paging, type People, type PeopleResource, type PeopleResourceResourceTypeOneOf, PeopleType, type PeopleTypeWithLiterals, type PermissionScope, type Person, type PersonMetaData, type PersonPersonOneOf, type Policy, type PolicyCondition, type PolicyStatement, PolicyType, type PolicyTypeWithLiterals, type PredefinedRole, type PredefinedRoleV2, type PredefinedRoles, type PredefinedRolesArea, type PredefinedRolesAreaV2, type RemoveMemberRequest, type RemoveMemberResponse, type Resource, ResourceType, type ResourceTypeWithLiterals, type Restriction, type RestrictionRestrictionsOneOf, type Role, type RoleInfo, type RoleInfoV2, RoleLevel, RoleLevelRestriction, type RoleLevelRestrictionWithLiterals, type RoleLevelWithLiterals, RoleVisibility, type RoleVisibilityWithLiterals, type RolesInfoFilter, type ScopeArea, ScopeLevel, type ScopeLevelWithLiterals, type SearchTeamOptions, type SearchTeamRequest, type SearchTeamResponse, type SimpleCondition, SimpleConditionOperator, type SimpleConditionOperatorWithLiterals, type SimpleConditionValue, type SimpleConditionValueValueOneOf, type SiteResourceContext, type SiteRestriction, type Subject, type SubjectAssignments, type SubjectContext, SubjectContextType, type SubjectContextTypeWithLiterals, SubjectType, type SubjectTypeWithLiterals, type TeamMember, type TeamMemberV3, type TeamMemberV3MembersOneOf, type UpdateTeamMemberAssignmentsOptions, type UpdateTeamMemberAssignmentsRequest, type UpdateTeamMemberAssignmentsResponse, type User, type UserV3, Visibility, type VisibilityWithLiterals, getRolesInfo, removeMember, searchTeam, updateTeamMemberAssignments };
